@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 """
 Package SIMPLEBLOG -- Simple Python blog system
-Copyright (C) 2012 by Peter A. Donis
+Copyright (C) 2012-2013 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -15,7 +15,6 @@ from datetime import datetime
 from functools import wraps
 from operator import attrgetter
 
-from plib.stdlib.builtins import first
 from plib.stdlib.decotools import (
     cached_method, cached_property, memoize_generator)
 from plib.stdlib.ini import PIniFile
@@ -26,7 +25,7 @@ from plib.stdlib.localize import (
     monthname, monthname_long)
 
 
-__version__ = "0.9"
+__version__ = "0.9.4"
 
 
 blogfile_exts = ["json"]
@@ -91,6 +90,7 @@ newline = os.linesep
 class BlogError(Exception):
     pass
 
+
 class BlogConfigError(BlogError):
     pass
 
@@ -178,11 +178,6 @@ class BlogConfigUser(object):
 
 # BASE
 
-class BlogMixin(BlogConfigUser):
-    """All entry, page, and blog mixins in extensions must subclass this class.
-    """
-    pass
-
 
 class BlogTemplateError(BlogError):
     pass
@@ -216,8 +211,10 @@ class BlogObject(BlogConfigUser):
             return read_blogfile(self.template_file(kind, format))
         except IOError:
             try:
-                return blogdata(pkgutil.get_data('simpleblog',
-                    "templates/{}".format(self.template_basename(kind, format))))
+                return blogdata(pkgutil.get_data(
+                    'simpleblog',
+                    "templates/{}".format(self.template_basename(kind, format))
+                ))
             except IOError:
                 raise BlogConfigError("template {}.{} not found".format(kind, format))
 
@@ -280,6 +277,7 @@ class extendable_attr(object):
         assert name == self._func.__name__
         getkey = '{0}_get_{1}'.format(etype, name)
         modkey = '{0}_mod_{1}'.format(etype, name)
+        
         @wraps(self._func)
         def meth(innerself, *args, **kwargs):
             # Check for extensions that might override the original function
@@ -288,9 +286,12 @@ class extendable_attr(object):
             if result is noresult:
                 result = self._func(innerself, *args, **kwargs)
             # Now check for extensions that want to modify the result
-            result = check_extensions(innerself, etype, modkey, args, kwargs,
-                result, True)
+            result = check_extensions(
+                innerself, etype, modkey, args, kwargs,
+                result, True
+            )
             return result
+        
         return meth
     
     def as_extended(self, cls, name):
@@ -343,10 +344,12 @@ def extendable(cls):
     # Implement post_init call at end of constructor
     initkey = '{}_post_init'.format(etype)
     oldinit = cls.__init__
+    
     @wraps(oldinit)
     def _newinit(self, *args, **kwargs):
         oldinit(self, *args, **kwargs)
         check_extensions(self, etype, initkey, result=noreturn)
+    
     cls.__init__ = _newinit
     
     return cls
@@ -605,7 +608,8 @@ class BlogEntries(BlogSource):
     
     @cached_property
     def entries(self):
-        return sorted(self._get_entries(),
+        return sorted(
+            self._get_entries(),
             key=attrgetter(self.entry_sort_key),
             reverse=self.entry_sort_reversed
         )
