@@ -2,7 +2,7 @@
 """
 Module INDEXES -- Simple Blog Index Generator Extension
 Sub-Package SIMPLEBLOG.EXTENSIONS
-Copyright (C) 2012 by Peter A. Donis
+Copyright (C) 2012-2013 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -13,7 +13,7 @@ from re import compile, sub
 
 from plib.stdlib.decotools import cached_property
 
-from simpleblog import BlogObject, BlogPage, prefixed_keys, newline
+from simpleblog import BlogObject, BlogPage, newline
 from simpleblog.extensions import BlogExtension
 
 
