@@ -2,7 +2,7 @@
 """
 Module TIMESTAMPS -- Simple Blog Timestamps Extension
 Sub-Package SIMPLEBLOG.EXTENSIONS
-Copyright (C) 2012 by Peter A. Donis
+Copyright (C) 2012-2013 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -10,9 +10,9 @@ See the LICENSE and README files for more information
 
 from datetime import datetime
 
-from simpleblog import BlogMixin, extendable_property, extendable_method
+from simpleblog import extendable_property, extendable_method
 from simpleblog.caching import cached
-from simpleblog.extensions import BlogExtension
+from simpleblog.extensions import BlogExtension, EntryMixin
 
 
 timestamps_file = BlogExtension.config.get('timestamps_file', u"timestamps")
@@ -20,7 +20,7 @@ timestamps_file = BlogExtension.config.get('timestamps_file', u"timestamps")
 timestamp_cache_format = "%Y-%m-%d %H:%M"
 
 
-class TimestampEntryMixin(BlogMixin):
+class TimestampEntryMixin(EntryMixin):
     
     @extendable_method()
     def string_from_datetime(self, dt, fmt):
@@ -42,7 +42,5 @@ class TimestampsExtension(BlogExtension):
     """Cache entry timestamps.
     """
     
-    entry_mixin = TimestampEntryMixin
-    
     def entry_get_timestamp(self, entry):
         return entry.datetime_from_string(entry.timestamp_str, timestamp_cache_format)
